Default FALSE. If TRUE, this saves a plane with the shadow texture below the model.
water_attenuation
Default 0, no attenuation. Amount that light should be attenuated when traveling through water.
water_surface_color
Default TRUE. Whether the water should have a colored surface or not. This is in contrast to
setting a non-zero water attenuation, where the color comes from the attenuation of light in the water itself.