Learn R Programming

rayshader (version 0.41.2)

make_base: make_base

Description

Makes the base below the 3D elevation map.

Usage

make_base(
  heightmap,
  basedepth = 0,
  basecolor = "grey20",
  zscale = 1,
  soil = FALSE,
  soil_freq = 0.1,
  soil_levels = 8,
  soil_color1 = "black",
  soil_color2 = "black",
  soil_gradient = 0,
  gradient_darken = 1
)

Arguments

heightmap

A two-dimensional matrix, where each entry in the matrix is the elevation at that point. All points are assumed to be evenly spaced.

basedepth

Default 0.

basecolor

Default grey20.

zscale

Default 1. The ratio between the x and y spacing (which are assumed to be equal) and the z axis. For example, if the elevation levels are in units of 1 meter and the grid values are separated by 10 meters, zscale would be 10.