Makes the water in the 3D elevation map.
make_water(
heightmap,
waterheight = mean(heightmap),
watercolor = "lightblue",
zscale = 1,
wateralpha = 0.5
)A two-dimensional matrix, where each entry in the matrix is the elevation at that point. All points are assumed to be evenly spaced.
Default 0.
Default blue.
Default 1. The ratio between the x and y spacing (which are assumed to be equal) and the z axis. For example, if the elevation levels are in units
of 1 meter and the grid values are separated by 10 meters, zscale would be 10.
Default 0.5. Water transparency.