- focus
Focal point. Defaults to the center of the bounding box. Depth in which to blur, in distance to the camera plane.
- focallength
Default 1. Focal length of the virtual camera.
- fstop
Default 1. F-stop of the virtual camera.
- filename
The filename of the image to be saved. If this is not given, the image will be plotted instead.
- preview_focus
Default FALSE. If TRUE, a red line will be drawn across the image
showing where the camera will be focused.
- bokehshape
Default circle. Also built-in: hex. The shape of the bokeh.
- bokehintensity
Default 3. Intensity of the bokeh when the pixel intensity is greater than bokehlimit.
- bokehlimit
Default 0.8. Limit after which the bokeh intensity is increased by bokehintensity.
- rotation
Default 0. Number of degrees to rotate the hexagon bokeh shape.
- aberration
Default 0. Adds chromatic aberration to the image. Maximum of 1.
- transparent_water
Default FALSE. If TRUE, depth is determined without water layer. User will have to re-render the water
layer with render_water() if they want to recreate the water layer.
- heightmap
Default NULL. The height matrix for the scene. Passing this will allow render_depth()
to automatically redraw the water layer if transparent_water = TRUE.
- zscale
Default NULL. The zscale value for the heightmap. Passing this will allow render_depth()
to automatically redraw the water layer if transparent_water = TRUE.
- title_text
Default NULL. Text. Adds a title to the image, using magick::image_annotate.
- title_offset
Default c(20,20). Distance from the top-left (default, gravity direction in
image_annotate) corner to offset the title.
- title_color
Default black. Font color.
- title_size
Default 30. Font size in pixels.
- title_font
Default sans. String with font family such as "sans", "mono", "serif", "Times", "Helvetica",
"Trebuchet", "Georgia", "Palatino" or "Comic Sans".
- title_bar_color
Default NA. If a color, this will create a colored bar under the title.
- title_bar_alpha
Default 0.5. Transparency of the title bar.
- title_just
Default left. Justification of the title.
- image_overlay
Default NULL. Either a string indicating the location of a png image to overlay
over the image (transparency included), or a 4-layer RGBA array. This image will be resized to the
dimension of the image if it does not match exactly.
- vignette
Default FALSE. If TRUE or numeric, a camera vignetting effect will be added to the image.
1 is the darkest vignetting, while 0 is no vignetting. If vignette is a length-2 vector, the second entry will
control the blurriness of the vignette effect.
- vignette_color
Default "black". Color of the vignette.
- vignette_radius
Default 1.3. Radius of the vignette, as a porportion of the image dimensions.
- progbar
Default TRUE if in an interactive session. Displays a progress bar.
- software_render
Default FALSE. If TRUE, rayshader will use the rayvertex package to render the snapshot, which
is not constrained by the screen size or requires OpenGL.
- width
Default NULL. Optional argument to pass to rgl::snapshot3d() to specify the
width when software_render = TRUE..
- height
Default NULL. Optional argument to pass to rgl::snapshot3d() to specify the
height when software_render = TRUE.
- camera_location
Default NULL. Custom position of the camera. The FOV, width, and height arguments will still
be derived from the rgl window.
- camera_lookat
Default NULL. Custom point at which the camera is directed. The FOV, width, and height arguments will still
be derived from the rgl window.
- background
Default "white". Background color when software_render = TRUE.
- text_angle
Default NULL, which forces the text always to face the camera. If a single angle (degrees),
will specify the absolute angle all the labels are facing. If three angles, this will specify all three orientations
(relative to the x,y, and z axes) of the text labels.
- text_size
Default 10. Height of the text.
- text_offset
Default c(0,0,0). Offset to be applied to all text labels.
- point_radius
Default 0.5. Radius of 3D points (rendered with render_points().
- line_offset
Default 1e-7. Small number indicating the offset in the scene to apply to lines if using software rendering. Increase this if your lines
aren't showing up, or decrease it if lines are appearing through solid objects.
- cache_scene
Default FALSE. Whether to cache the current scene to memory so it does not have to be converted to a raymesh object
each time render_snapshot() is called. If TRUE and a scene has been cached, it will be used when rendering.
- reset_scene_cache
Default FALSE. Resets the scene cache before rendering.
- print_scene_info
Default FALSE. If TRUE, it will print the position and lookat point of the camera.
- instant_capture
Default TRUE if interactive, FALSE otherwise. If FALSE, a slight delay is added
before taking the snapshot. This can help stop prevent rendering issues when running scripts.
- clear
Default FALSE. If TRUE, the current rgl device will be cleared.
- bring_to_front
Default FALSE. Whether to bring the window to the front when rendering the snapshot.
- ...
Additional parameters to pass to rayvertex::rasterize_scene().