Learn R Programming

rayshader (version 0.41.2)

save_3dprint: Save 3D Print

Description

Writes a stereolithography (STL) file that can be used in 3D printing.

Usage

save_3dprint(filename, maxwidth = 125, unit = "mm", rotate = FALSE)

Value

Writes an STL file to filename. Regardless of the unit displayed, the output STL is in millimeters.

Arguments

filename

String with the filename. If .stl is not at the end of the string, it will be appended automatically.

maxwidth

Default 125. Desired maximum width of the 3D print in millimeters. Uses the units set in unit argument. Can also pass in a string, "125mm" or "5in".

unit

Default mm. Units of the maxwidth argument. Can also be set to inches with in.

rotate

Default TRUE. If FALSE, the map will be printing on its side. This may improve resolution for some 3D printing types.

Examples

Run this code
filename_stl = tempfile()

#Save the STL file into `filename_stl`
if(run_documentation()) {
volcano |>
 sphere_shade() |>
 plot_3d(volcano,zscale=3)
render_snapshot()
save_3dprint(filename_stl)
}

#Save the STL file into `filename_stl`, setting maximum width to 100 mm
if(run_documentation()) {
volcano |>
 sphere_shade() |>
 plot_3d(volcano,zscale=3)
render_snapshot()
save_3dprint(filename_stl, maxwidth = 100)
}

#'#Save the STL file into `filename_stl`, setting maximum width to 4 inches
if(run_documentation()) {
volcano |>
 sphere_shade() |>
 plot_3d(volcano,zscale=3)
render_snapshot()
save_3dprint(filename_stl, maxwidth = 4, unit = "in")
}
#'#'#Save the STL file into `filename_stl`, setting maximum width (character) to 120mm
if(run_documentation()) {
volcano |>
 sphere_shade() |>
 plot_3d(volcano,zscale=3)
render_snapshot()
save_3dprint(filename_stl, maxwidth = "120mm")
}

Run the code above in your browser using DataLab