Learn R Programming

rayshader (version 0.41.2)

monterey_counties_sf: California County Data Around Monterey Bay

Description

This dataset is an sf object containing polygon data from the U.S. Department of Commerce with selected geographic and cartographic information from the U.S. Census Bureau's Master Address File / Topologically Integrated Geographic Encoding and Referencing (MAF/TIGER) Database (MTDB). This data has been trimmed to only include 26 features in the extent of the montereybay dataset.

Usage

monterey_counties_sf

Arguments

Format

An sf object with MULTIPOLYGON geometry.

Examples

Run this code
# This is the full code (commented out) used to generate this dataset from the original data:
#counties = sf::st_read("tl_2016_06_cousub.shp")
#monterey_counties_sf = sf::st_crop(counties, attr(montereybay,"extent"))

Run the code above in your browser using DataLab