- hillshade
Array (or matrix) of hillshade to be written.
- filename
String with the filename. If .png is not at the end of the string, it will be appended automatically.
- title_text
Default NULL. Text. Adds a title to the image, using magick::image_annotate().
- title_offset
Default c(20,20). Distance from the top-left (default, gravity direction in
image_annotate) corner to offset the title.
- title_color
Default black. Font color.
- title_size
Default 30. Font size in pixels.
- title_font
Default sans. String with font family such as "sans", "mono", "serif", "Times", "Helvetica",
"Trebuchet", "Georgia", "Palatino" or "Comic Sans".
- title_style
Default normal. Font style (e.g. italic).
- title_bar_color
Default NA. If a color, this will create a colored bar under the title.
- title_bar_alpha
Default 0.5. Transparency of the title bar.
- title_just
Default left. Position of the title.